package info.textgrid.utils.linkrewriter;

import info.textgrid._import.ImportObject;
import info.textgrid._import.ImportSpec;
import info.textgrid._import.RevisionPolicyType;
import info.textgrid._import.RewriteMethod;

import java.util.Collection;
import java.util.Map;

import com.google.common.collect.Maps;

public class ImportMapping {

	private final Map<String, ImportObject> textgridMap = Maps.newHashMap();
	private final Map<String, ImportObject> localMap = Maps.newHashMap();
	private ImportSpec importSpec;

	public ImportObject getImportObjectForTextGridURI(final String textGridURI) {
		return textgridMap.get(textGridURI);
	}

	public ImportObject getImportObjectForLocalURI(final String localURI) {
		return localMap.get(localURI);
	}

	public void add(final ImportObject... importObjects) {
		for (final ImportObject importObject : importObjects) {
			textgridMap.put(importObject.getTextgridUri(), importObject);
			localMap.put(importObject.getLocalData(), importObject);
		}
	}

	public ImportMapping add(final String textgridURI, final String localURI, final String localMetadata,
			final RewriteMethod rewriteMethod) {
		final ImportObject importObject = new ImportObject();
		importObject.setTextgridUri(textgridURI);
		importObject.setLocalData(localURI);
		if (localMetadata != null)
			importObject.setLocalMetadata(localMetadata);
		importObject.setRewriteMethod(rewriteMethod);
		add(importObject);

		return this;
	}

	public Collection<? extends ImportObject> getImportObjects() {
		return textgridMap.values();
	}

	public ImportSpec toImportSpec() {
		if (importSpec == null)
			importSpec = new ImportSpec();
		else
			importSpec.getImportObject().clear();

		importSpec.getImportObject().addAll(textgridMap.values());
		return importSpec;
	}

	public ImportMapping(final ImportSpec importSpec) {
		this();
		for (final ImportObject object : importSpec.getImportObject())
			add(object);
		this.importSpec = importSpec;
	}

	public RevisionPolicyType getImportRevisionPolicy() {
		if (importSpec != null && importSpec.getRevisionPolicy() != null && importSpec.getRevisionPolicy().getImport() != null)
			return importSpec.getRevisionPolicy().getImport();
		else
			return RevisionPolicyType.ACTUAL;
	}

	public ImportMapping() {
		super();
	}
}
